==> nextcloud-23.0.8.tgz: nextcloud/apps/password_policy/l10n/en_GB.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Password is among the 1,000,000 most common ones. Please make it unique.",
    "Password is present in compromised password list. Please choose a different password." : "Password is present in compromised password list. Please choose a different password.",
    "Password needs to contain at least one numeric character." : "Password needs to contain at least one numeric character.",
    "Password needs to contain at least one special character." : "Password needs to contain at least one special character.",
    "Password needs to contain at least one lower and one upper case character." : "Password needs to contain at least one lower and one upper case character.",
    "Password policy" : "Password policy",
    "Allows admins to configure a password policy" : "Allows admins to configure a password policy",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length",
    "Saved" : "Saved",
    "Forbid common passwords" : "Forbid common passwords",
    "Enforce upper and lower case characters" : "Enforce upper and lower case characters",
    "Enforce numeric characters" : "Enforce numeric characters",
    "Enforce special characters" : "Enforce special characters",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Check password against the list of breached passwords from haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set.",
    "Unknown error" : "Unknown error"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.4.tgz: nextcloud/apps/password_policy/l10n/en_GB.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Password is expired, please use forgot password method to reset",
    "Password must not have been used recently before." : "Password must not have been used recently before.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Password is among the 1,000,000 most common ones. Please make it unique.",
    "Password is present in compromised password list. Please choose a different password." : "Password is present in compromised password list. Please choose a different password.",
    "Password needs to be at least %s characters long." : "Password needs to be at least %s characters long.",
    "Password needs to contain at least one numeric character." : "Password needs to contain at least one numeric character.",
    "Password needs to contain at least one special character." : "Password needs to contain at least one special character.",
    "Password needs to contain at least one lower and one upper case character." : "Password needs to contain at least one lower and one upper case character.",
    "Password policy" : "Password policy",
    "Allows admins to configure a password policy" : "Allows admins to configure a password policy",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length",
    "Saved" : "Saved",
    "Minimum password length" : "Minimum password length",
    "User password history" : "User password history",
    "Number of days until user password expires" : "Number of days until user password expires",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Number of login attempts before the user account is blocked (0 for no limit)",
    "Forbid common passwords" : "Forbid common passwords",
    "Enforce upper and lower case characters" : "Enforce upper and lower case characters",
    "Enforce numeric characters" : "Enforce numeric characters",
    "Enforce special characters" : "Enforce special characters",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Check password against the list of breached passwords from haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set.",
    "Unknown error" : "Unknown error",
    "Minimal length has to be a non negative number" : "Minimal length has to be a non negative number",
    "History size has to be a non negative number" : "History size has to be a non negative number",
    "Expiration days have to be a non negative number" : "Expiration days have to be a non negative number",
    "Maximum login attempts have to be a non negative number" : "Maximum login attempts have to be a non negative number",
    "Error while saving" : "Error while saving"
},
"nplurals=2; plural=(n != 1);");
